package de.duehl.vocabulary.japanese.launcher.logic.oldjars;

import java.util.List;

import de.duehl.basics.io.FileHelper;
import de.duehl.basics.system.SystemTools;
import de.duehl.basics.version.Version;
import de.duehl.vocabulary.japanese.launcher.VocabularyTrainerLauncherVersion;

import static de.duehl.vocabulary.japanese.launcher.logic.selfcheck.LauncherSelfUpdateChecker.LAUNCHER_JAR_NAME_START;

/**
 * Diese Klasse sucht ggf. vorhandene Jar-Files von alten Versionen des Launchers und entfernt
 * diese.
 *
 * @version 1.01     2024-12-07
 * @author Christian Dühl
 */

public class OldLauncherJarsRemover {

    /** Die Anzahl der entfernten Jars. */
    private int numberOfRemovedJars;

    /** Sucht ale Jars und entfernt sie. */
    public void findAndRemove() {
        Version actualVersion = new VocabularyTrainerLauncherVersion().getVersion();

        String dir = SystemTools.getCurrentWorkingDirectory();
        List<String> launcherJarFilenames = FileHelper.findFilesInMainDirectoryNio2(dir,
                LAUNCHER_JAR_NAME_START, ".jar");

        numberOfRemovedJars = 0;

        for (String launcherJarFilename : launcherJarFilenames) {
            String versionString = Version.extractVersionFromJarFilename(launcherJarFilename,
                    LAUNCHER_JAR_NAME_START);
            Version version = new Version(versionString, "interessiert nicht");
            if (actualVersion.isNewerThan(version)) {
                System.out.println("Entferne alte Launcher-Jar-Datei " + launcherJarFilename);
                FileHelper.deleteFile(launcherJarFilename);
                ++numberOfRemovedJars;
            }
        }
    }

    /** Getter für die Anzahl der entfernten Jars. */
    public int getNumberOfRemovedJars() {
        return numberOfRemovedJars;
    }

}
