package de.duehl.vocabulary.japanese.launcher.ui;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Image;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTextArea;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;

import de.duehl.swing.ui.GuiTools;
import de.duehl.swing.ui.dialogs.base.NonModalFrameDialogBase;
import de.duehl.vocabulary.japanese.common.chan.Chan;
import de.duehl.vocabulary.japanese.common.ui.resources.IconDefinitions;
import de.duehl.vocabulary.japanese.launcher.VocabularyTrainerLauncherVersion;

/**
 * Diese Klasse stellt die grafische Oberfläche des Launchers des Vokabeltrainers dar.
 *
 * @version 1.01     2024-12-11
 * @author Christian Dühl
 */

public class LauncherGui extends NonModalFrameDialogBase {

    private static final String DIALOG_TITLE = "Launcher des " + Chan.CHAN_NAME + "s " +
            "Vokabel-Trainer (" + VocabularyTrainerLauncherVersion.getOnlyVersion() + ")";
    private static final Image PROGRAM_IMAGE = IconDefinitions.loadProgramImage();


    /** Der StringBuilder für den Text, der beim Starten des Vokabeltrainers angezeigt wird. */
    private final StringBuilder splashTextBuilder;

    /** Das Textfeld, wo die Daten über den Einleseprozess angezeigt werden. */
    private final JTextArea textArea;

    /** Konstruktor. */
    public LauncherGui() {
        super(PROGRAM_IMAGE, DIALOG_TITLE);

        addClosingWindowListener(() -> quit());
        //addEscapeBehaviour();

        GuiTools.setNiceLayoutManager();

        splashTextBuilder = new StringBuilder();
        textArea = new JTextArea();

        fillDialog();
    }

    private void quit() {
        String title = "Soll das Programm beendet werden";
        String message = "Soll das Programm wirklich sofort beendet werden?";
        boolean quit = GuiTools.askUser(getWindowAsComponent(), title, message);
        if (quit) {
            appendMessage("ABBRUCH DURCH DEN BENUTZER");
            printSplashTextAndExit();
        }
    }

    @Override
    protected void populateDialog() {
        initElements();

        add(createPicturePart(), BorderLayout.WEST);
        add(GuiTools.createScrollPane(textArea), BorderLayout.CENTER);
    }

    private void initElements() {
        initTextArea();
    }

    private void initTextArea() {
        textArea.setRows(45);
        textArea.setColumns(120);
        textArea.setEditable(false);
    }

    private Component createPicturePart() {
        Image image = IconDefinitions.loadProgramImage();
        JLabel label = new JLabel(new ImageIcon(image));
        // TODO Später ein Chan-Bild!
        return label;
    }

    /** Fügt eine Nachricht hinzu. */
    public void appendMessage(String message) {
        appendMessageToSplashTextBuilder(message);
        appendMessageToTextArea(message);
    }

    private void appendMessageToSplashTextBuilder(String message) {
        splashTextBuilder.append(message).append("\n");
    }

    private void appendMessageToTextArea(String message) {
        try {
            tryToAppendMessageToTextArea(message);
        }
        catch (BadLocationException e) {
            throw new RuntimeException("Kann die Nachricht [" + message + "] nicht an das Ende "
                    + "des Dokuments der JTextArea des SplashScreens anhängen.");
        }
    }

    private void tryToAppendMessageToTextArea(String message) throws BadLocationException {
        Document doc = textArea.getDocument();
        doc.insertString(doc.getLength(), message + "\n", null);
        textArea.setCaretPosition(textArea.getDocument().getLength());
    }

    /** Getter für den Text, der beim Starten des Vokabeltrainers angezeigt wurde. */
    public String getSplashText() {
        return splashTextBuilder.toString();
    }

    /** Gibt den Text aus und beendet das Programm sofort. */
    public void printSplashTextAndExit() {
        System.out.println(getSplashText());
        closeDialog();
        System.exit(1);
    }

}
