package de.duehl.vocabulary.japanese.launcher.update.vocables.download;

import java.util.List;

import de.duehl.basics.io.Charset;
import de.duehl.basics.io.FileHelper;

import static de.duehl.vocabulary.japanese.common.persistence.SessionManager.VOCABLE_TRAINER_DIRECTORY;
import static de.duehl.vocabulary.japanese.launcher.update.vocables.VocablesUpdater.say;

/**
 * Diese Klasse stellt Methoden rund um das Passwort für den Download der Vokabeln mit MP3-Dateien
 * zur Verfügung.
 *
 * @version 1.01     2024-12-07
 * @author Christian Dühl
 */

public class VocableUpdateUserPasword {

    /**
     * Der Name der Datei mit dem Passwort für die Vokabeln mit Aussprache ohne Pfad.
     *
     * Diese Datei liegt (bei den anderen Benutzern) im .JapaneseVocableTrainer-Verzeichnis im
     * Benutzerverzeichnis und sollte nicht mit meiner Passwortdatei zum Upload verwechselt werden,
     * welche bei mir neben dem Programmcode liegt.
     */
    private static final String USER_PASSWORT_BARE_FILENAME =
            "Vokabeln_mit_Aussprache_Download_Passwort.txt";

    /**
     * Liest das Passwort aus der Datei des Benutzers. Wenn diese nicht vorhanden ist oder das
     * Passwort darin nicht geeignet scheint, wird das Passwort leer zurück gegeben.
     */
    public static String readPassword() {
        say("readPassword()");
        String filename = FileHelper.concatPathes(VOCABLE_TRAINER_DIRECTORY,
                USER_PASSWORT_BARE_FILENAME);
        say("    filename = " + filename);
        if (!FileHelper.isFile(filename)) {
            say("    Datei nicht vorhanden.");
            return "";
        }
        say("    Datei ist vorhanden.");
        List<String> lines = FileHelper.readFileToList(filename, Charset.UTF_8);
        if (lines.isEmpty()) {
            return "";
        }
        else {
            String password = lines.get(0).strip();
            if (password.length() < 8) {
                say("    Passwort ist zu kurz und wird auf leer gesetzt.");
                return "";
            }
            else {
                return password;
            }
        }
    }

    /** Speichert das Passwort in der Datei des Benutzers. */
    public static void savePassword(String password) {
        say("readPassword()");
        String filename = FileHelper.concatPathes(VOCABLE_TRAINER_DIRECTORY,
                USER_PASSWORT_BARE_FILENAME);
        say("    filename = " + filename);
        FileHelper.writeTextToFile(password, filename, Charset.UTF_8);
    }

}
