package de.duehl.vocabulary.japanese.launcher.update.vocables.error;

import javax.swing.SwingUtilities;

import de.duehl.basics.logic.ErrorHandler;
import de.duehl.swing.ui.dialogs.base.AbstractDialogBase;

/**
 * Diese Klasse zeigt fatale Fehler an (wird nur im Launcher verwendet).
 *
 * @version 1.01     2024-12-11
 * @author Christian Dühl
 */

public class FatalErrorHandler {

    /** Die grafische Oberfläche des Vokabel-Trainers bzw. der Gui des Launchers. */
    private final AbstractDialogBase gui;

    /**
     * Konstruktor.
     *
     * @param gui
     *            Die grafische Oberfläche des Vokabel-Trainers bzw. der Gui des Launchers.
     */
    public FatalErrorHandler(AbstractDialogBase gui) {
        this.gui = gui;
    }

    /** Zeigt den Fehler im EDT an. */
    public void showError(Exception exception) {
        SwingUtilities.invokeLater(() -> showErrorInEdt(exception));
    }

    private void showErrorInEdt(Exception exception) {
        ErrorHandler error = gui.createErrorHandler();

        error.error("Es trat ein Fehler beim Aktualisieren der Vokabeln auf:\n"
                + exception.getMessage(), exception);

        endLongTimeProcessAndCloseGui();
    }

    /** Beendet die GlassPane und auch das Programm. */
    public void endLongTimeProcessAndCloseGui() {
        gui.endLongTimeProcess();
        // Leider kann man hier den SplashText nicht ausgeben, weil man die LauncherGui aus
        // Common nicht kennt, aber immerhin...
        gui.closeDialog();
        System.exit(1);
    }

}
